@@ -8,6 +8,8 @@
 #' @param pred Products to predict for
 #' @param rate String with name of the variable with product ratings
 #' @param data_filter Expression entered in, e.g., Data > View to filter the dataset in Radiant. The expression should be a string (e.g., "training == 1")
+#' @param arr Expression to arrange (sort) the data on (e.g., "color, desc(price)")
+#' @param rows Rows to select from the specified dataset
 #' @param envir Environment to extract data from
 #'
 #' @return A data.frame with the original data and a new column with predicted ratings
@@ -16,19 +18,19 @@
 #' @seealso \code{\link{plot.crs}} to plot results if the actual ratings are available
 #'
 #' @examples
-#' crs(ratings, id = "Users", prod = "Movies", pred = c("M6", "M7", "M8", "M9", "M10"),
-#'   rate = "Ratings", data_filter = "training == 1") %>% str()
+#' crs(ratings,
+#'   id = "Users", prod = "Movies", pred = c("M6", "M7", "M8", "M9", "M10"),
+#'   rate = "Ratings", data_filter = "training == 1"
+#' ) %>% str()
 #' @importFrom dplyr distinct_at
 #'
 #' @export
-crs <- function(
-                dataset, id, prod, pred, rate,
-                data_filter = "", envir = parent.frame()
-) {
-
+crs <- function(dataset, id, prod, pred, rate,
+                data_filter = "", arr = "", rows = NULL,
+                envir = parent.frame()) {
   vars <- c(id, prod, rate)
   df_name <- if (!is_string(dataset)) deparse(substitute(dataset)) else dataset
-  uid <- get_data(dataset, id, filt = data_filter, na.rm = FALSE, envir = envir) %>% unique()
+  uid <- get_data(dataset, id, filt = data_filter, arr = arr, rows = rows, na.rm = FALSE, envir = envir) %>% unique()
   dataset <- get_data(dataset, vars, na.rm = FALSE, envir = envir)
 
   ## creating a matrix layout
@@ -74,14 +76,14 @@ crs <- function(
 
   ## average scores and rankings
   avg <- dataset[uid, , drop = FALSE] %>%
-    select(nind) %>%
+    .[, nind, drop = FALSE] %>%
     summarise_all(mean, na.rm = TRUE)
   ravg <- avg
   ravg[1, ] <- min_rank(desc(as.numeric(avg)))
   ravg <- mutate_all(ravg, as.integer)
 
   ## actual scores and rankings (if available, else will be NA)
-  act <- dataset[-uid, , drop = FALSE] %>% select(nind)
+  act <- dataset[-uid, , drop = FALSE] %>% .[, nind, drop = FALSE]
   ract <- act
 
   if (nrow(act) == 0) {
@@ -90,14 +92,14 @@ crs <- function(
   }
 
   rank <- apply(act, 1, function(x) as.integer(min_rank(desc(x)))) %>%
-    {if (length(pred) == 1) . else t(.)}
+    (function(x) if (length(pred) == 1) x else t(x))
   ract[, pred] <- rank
   ract <- bind_cols(idv[-uid, , drop = FALSE], ract)
   act <- bind_cols(idv[-uid, , drop = FALSE], act)
 
   ## CF calculations per row
-  ms <- apply(select(dataset, -nind), 1, function(x) mean(x, na.rm = TRUE))
-  sds <- apply(select(dataset, -nind), 1, function(x) sd(x, na.rm = TRUE))
+  ms <- apply(dataset[, -nind, drop = FALSE], 1, function(x) mean(x, na.rm = TRUE))
+  sds <- apply(dataset[, -nind, drop = FALSE], 1, function(x) sd(x, na.rm = TRUE))
 
   ## to forego standardization
   # ms <- ms * 0
@@ -125,9 +127,8 @@ crs <- function(
 
   ## Ranking based on CF
   rcf <- cf
-  rank <- apply(select(cf, -1), 1, function(x) as.integer(min_rank(desc(x)))) %>% {
-    if (length(pred) == 1) . else t(.)
-  }
+  rank <- apply(select(cf, -1), 1, function(x) as.integer(min_rank(desc(x)))) %>%
+    (function(x) if (length(pred) == 1) x else t(x))
   rcf[, pred] <- rank
 
   recommendations <-
@@ -135,7 +136,7 @@ crs <- function(
       bind_cols(
         gather(act, "product", "rating", -1, factor_key = TRUE),
         select_at(gather(ract, "product", "ranking", -1, factor_key = TRUE), .vars = "ranking"),
-        select_at(gather(cf, "product", "cf", -1, factor_key = TRUE), , .vars = "cf"),
+        select_at(gather(cf, "product", "cf", -1, factor_key = TRUE), .vars = "cf"),
         select_at(gather(rcf, "product", "cf_rank", -1, factor_key = TRUE), .vars = "cf_rank")
       ),
       data.frame(
@@ -166,17 +167,27 @@ crs <- function(
 #' @seealso \code{\link{plot.crs}} to plot results if the actual ratings are available
 #'
 #' @examples
-#' crs(ratings, id = "Users", prod = "Movies", pred = c("M6", "M7", "M8", "M9", "M10"),
-#'   rate = "Ratings", data_filter = "training == 1") %>% summary()
+#' crs(ratings,
+#'   id = "Users", prod = "Movies", pred = c("M6", "M7", "M8", "M9", "M10"),
+#'   rate = "Ratings", data_filter = "training == 1"
+#' ) %>% summary()
 #' @export
 summary.crs <- function(object, n = 36, dec = 2, ...) {
-  if (is.character(object)) return(cat(object))
+  if (is.character(object)) {
+    return(cat(object))
+  }
 
   cat("Collaborative filtering")
   cat("\nData       :", object$df_name)
-  if (!radiant.data::is_empty(object$data_filter)) {
+  if (!is.empty(object$data_filter)) {
     cat("\nFilter     :", gsub("\\n", "", object$data_filter))
   }
+  if (!is.empty(object$arr)) {
+    cat("\nArrange    :", gsub("\\n", "", object$arr))
+  }
+  if (!is.empty(object$rows)) {
+    cat("\nFilter     :", gsub("\\n", "", object$rows))
+  }
   cat("\nUser id    :", object$id)
   cat("\nProduct id :", object$prod)
   cat("\nPredict for:", paste0(object$pred, collapse = ", "), "\n")
@@ -225,12 +236,18 @@ summary.crs <- function(object, n = 36, dec = 2, ...) {
   if (n == -1) {
     cat("\n")
     format_df(object$recommendations, dec = dec) %>%
-      {.[. == "NA"] <- ""; .} %>%
+      (function(x) {
+        x[x == "NA"] <- ""
+        x
+      }) %>%
       print(row.names = FALSE)
   } else {
     head(object$recommendations, n) %>%
       format_df(dec = dec) %>%
-      {.[. == "NA"] <- ""; .} %>%
+      (function(x) {
+        x[x == "NA"] <- ""
+        x
+      }) %>%
       print(row.names = FALSE)
   }
 }
@@ -247,7 +264,9 @@ summary.crs <- function(object, n = 36, dec = 2, ...) {
 #'
 #' @export
 plot.crs <- function(x, ...) {
-  if (is.character(x)) return(x)
+  if (is.character(x)) {
+    return(x)
+  }
   if (any(is.na(x$act)) || all(is.na(x$cf))) {
     return("Plotting for Collaborative Filter requires the actual ratings associated\nwith the predictions")
   }
@@ -257,11 +276,12 @@ plot.crs <- function(x, ...) {
 
 
   p <- visualize(
-    x$recommendations, xvar = "cf", yvar = "rating",
+    x$recommendations,
+    xvar = "cf", yvar = "rating",
     type = "scatter", facet_col = "product", check = "line",
     custom = TRUE
   ) +
-    geom_segment(aes(x = 1, y = 1, xend = 5, yend = 5), color = "blue", size = .05) +
+    geom_segment(aes(x = 1, y = 1, xend = 5, yend = 5), color = "blue", linewidth = .05) +
     coord_cartesian(xlim = lim, ylim = lim) +
     labs(
       title = "Recommendations based on Collaborative Filtering",
@@ -296,4 +316,4 @@ store.crs <- function(dataset, object, name, ...) {
       call. = FALSE
     )
   }
-}
+}
\ No newline at end of file
